package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````*!<``#0```"``0$```(`!30`(``)
M`"@`&P`:``$``'#TB@``](H``/2*```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$`````````````````````BP```(L```4```````$`
M`0```,#]``#`_0$`P/T!`(`"``"4`@``!@```````0`"````R/T``,C]`0#(
M_0$`"`$```@!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DP/T`
M`,#]`0#`_0$`0`(``$`"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!0````#````1TY5`-<+S'VULT@6GW`[3E6S7?G'%Z)I!````!`````!
M````1TY5```````#`````@`````````1````2P````@````(`````9`0!"5`
M!(`H@``%H(90A(`!```+*`2,.(`208H```A+````3````$\```!3````5```
M`%P```!=````7@````````!@````80```&(```!C````9````&<`````````
M``````&O-.ANQ=\?SMY'+6M_FGPNQ9NVU&34?'94/)0A_^0.V7%8'.)'Q@&R
M`8MOK$OCP$+ZUX?"Y3\L6.^7>;KCDGS[H6Q@:PE#UF>OS&9"1=7LB0=PTS-B
MV^T5C"7,#3J7"W^IG)O@IP(*:AJ>4+_:5QNCX/M)````````````````````
M``````"0$0````````,`"P`````````"```````#`!8`U0(`````````````
M$@```/L``````````````!(```!<`@`````````````2````C@(`````````
M````$@```)8``````````````!(```!T`0`````````````2````$0$`````
M````````$@````$``````````````"````"Q`0`````````````2````0@$`
M````````````$@```#(!`````````````!(````#`@`````````````2````
M)`$`````````````$@```'X"`````````````!(````0```````````````@
M````D@$`````````````$@```!("`````````````!(``````0``````````
M```2````K`$`````````````$@```,X"`````````````!(````L````````
M```````@````AP(`````````````$@```$8``````````````!(```!C````
M```````````6````9`$`````````````$@```'8``````````````!(```#3
M```````````````2````AP``````````````$@```#P"`````````````!(`
M``#U`0`````````````2````=P(`````````````$@```+$#````````````
M`!(```"W```````````````2````W0(`````````````$0```.X!````````
M`````!(```#W`@`````````````1````*0(`````````````$@```#8"````
M`````````!(```!6`0`````````````2````(`(`````````````$@```.0`
M`````````````!(```!#`@`````````````2````!0$`````````````$@``
M`)8"`````````````!(```"+`0`````````````2````O0(`````````````
M$@```-D!`````````````!(```#\`0`````````````2````,`(`````````
M````$@```(8"`````````````!(```"_`0`````````````2````Y0(`````
M````````$@```-P"`````````````"$```"B```````````````2````N`$`
M````````````$@```'\!`````````````!(```"T`@`````````````2````
MVP(`````````````$0```'`"`````````````!$```#&```````````````1
M````4@(`````````````$@```&("`````````````!(````*`@``````````
M```2````2P$`````````````$@```$H"`````````````!(```!4````````
M```````2````QP$`````````````$@```!D"`````````````!(```#G`0``
M```````````2````KP(`````````````$@```)X"`````````````!(```"=
M`0`````````````B````#`0``%0``@``````$``7`+H#``"0-P``8`$``!(`
M#0`Q!```H"P```P(```2``T`U`$``(`4``"H`@``$@`-`#$#``#L(```!```
M`!(`#0!/`P``K#0``.0"```2``T`X@,``$```@``````$``7`%<$``#P(```
M@`(``!(`#0`7!```0``"```````0`!<`0@,``'`C```D````$@`-`&4#``!D
M*@``O````!(`#0#&`P``I$@```0````1``\`\`,```!&```8`0``$@`-`/L#
M``"0'P``7````!(`#0`#!```5``"```````0`!<`+`0``%0``@``````$``7
M`$4$```X*P``:`$``!(`#0#5`P`````"```````0`!8`B0,``)0C``"8`0``
M$@`-`#X$``!```(``````!``%@!D!```/``"``0````1`!8`VP,``"@7````
M````$@`-`",$``!T10``C````!(`#0#7`P`````"```````@`!8`GP,``"`K
M```8````$@`-`',#``#L'P````$``!(`#0"5`P``&$<``%P!```2``T`"P0`
M`%0``@``````$``7`&X$```L)0``.`4``!(`#0``7U]G;6]N7W-T87)T7U\`
M7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L
M;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R
M96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!0
M97)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V
M;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!097)L7V-R;V%K7VUE
M;6]R>5]W<F%P`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U
M;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`
M4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P97)L
M7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%]?8WAA7V9I
M;F%L:7IE`')E860`<W1R8VAR`&=E='!I9`!M96UM;W9E`%]?;&EB8U]S=&%R
M=%]M86EN`%]?9G!R:6YT9E]C:&L`<W1R8VUP`&]P96XV-`!U;FQI;FL`<W1R
M=&]K`&UE;7-E=`!S=')N8VUP`&=E='5I9`!M96UC:'(`8VQO<V5D:7(`<W1R
M<W1R`')M9&ER`&-L;W-E`'-T<FQE;@!S=')D=7``<F5A;&QO8P!R96%D9&ER
M-C0`86)O<G0`7U]S<')I;G1F7V-H:P!S=&1E<G(`;65M8W!Y`'-T<G)C:'(`
M;'-T870V-`!O<&5N9&ER`&QS965K-C0`7U]E<G)N;U]L;V-A=&EO;@!E>&ET
M`')E861L:6YK`%]?<W1A8VM?8VAK7V9A:6P`86-C97-S`&UK9&ER`%]?96YV
M:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P
M97)L+G-O+C4N,S8`;&EB8RYS;RXV`&QD+6QI;G5X+G-O+C,`<&%R7V-U<G)E
M;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A
M<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE
M`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE
M86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`7U]B<W-?<W1A<G1?
M7P!S:&%?=7!D871E`'AS7VEN:70`7U]E;F1?7P!?7V)S<U]E;F1?7P!?7V)S
M<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?:6YI
M=%]E;G8`1TQ)0D-?,BXT`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P``````````
M`@`!``(``@`!``$``0`!``(``0`!``(``0`"``$``0`"``(``@`"``$``P`!
M``$``0`!``$``0`"``(``@`"``$``@`"``0``@`"``$``@`!``(``0`"``(`
M`@`"``(``@`#``(``@`"``$``@`!``(``@`"``$``@`"``(``0`"``$`!0`"
M``(``@`"``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`C`P``$````"`````4:6D-```$
M`'L$`````````0`#`!D#```0`````````+21E@8```4`A00``!````"SD98&
M```#`)`$```0````%&EI#0```@![!````````,#]`0`7````Q/T!`!<```#\
M_P$`%P````0``@`7````#``"`!<````0``(`%P```!@``@`7````'``"`!<`
M```@``(`%P```"0``@`7````*``"`!<````P``(`%P```#0``@`7````/``"
M`!<```#,_P$`%0D``-#_`0`5"@``U/\!`!41``#8_P$`%1<``-S_`0`3&@``
MX/\!`!4;``#D_P$`%1P``.C_`0`5)```[/\!`!4F``#P_P$`%3T``/3_`0`5
M/@``^/\!`!5*``#<_@$`%@,``.#^`0`6!```Y/X!`!8%``#H_@$`%@8``.S^
M`0`6!P``\/X!`!8(``#T_@$`%@H``/C^`0`6"P``_/X!`!8,````_P$`%@T`
M``3_`0`6#@``"/\!`!8/```,_P$`%A```!#_`0`6$@``%/\!`!83```8_P$`
M%A0``!S_`0`6%0``(/\!`!86```D_P$`%A@``"C_`0`6&0``+/\!`!8=```P
M_P$`%AX``#3_`0`6'P``./\!`!8@```\_P$`%B$``$#_`0`6(@``1/\!`!8C
M``!(_P$`%B4``$S_`0`6)P``4/\!`!8H``!4_P$`%BD``%C_`0`6*@``7/\!
M`!8K``!@_P$`%BP``&3_`0`6+0``:/\!`!8N``!L_P$`%B\``'#_`0`6,```
M=/\!`!8Q``!X_P$`%C(``'S_`0`6,P``@/\!`!8T``"$_P$`%C4``(C_`0`6
M-@``C/\!`!8X``"0_P$`%CD``)3_`0`6.@``F/\!`!8[``"<_P$`%C\``*#_
M`0`60```I/\!`!9!``"H_P$`%D(``*S_`0`60P``L/\!`!9$``"T_P$`%D4`
M`+C_`0`61@``O/\!`!9'``#`_P$`%D@``,3_`0`620``R/\!`!9*```(0"WI
M=`$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[E).T!``#&C^(>RHSB)/V\Y0#&C^(>
MRHSB'/V\Y0#&C^(>RHSB%/V\Y0#&C^(>RHSB#/V\Y0#&C^(>RHSB!/V\Y0#&
MC^(>RHSB_/R\Y0#&C^(>RHSB]/R\Y0#&C^(>RHSB[/R\Y0#&C^(>RHSBY/R\
MY0#&C^(>RHSBW/R\Y0#&C^(>RHSBU/R\Y0#&C^(>RHSBS/R\Y0#&C^(>RHSB
MQ/R\Y0#&C^(>RHSBO/R\Y0#&C^(>RHSBM/R\Y0#&C^(>RHSBK/R\Y0#&C^(>
MRHSBI/R\Y0#&C^(>RHSBG/R\Y0#&C^(>RHSBE/R\Y0#&C^(>RHSBC/R\Y0#&
MC^(>RHSBA/R\Y0#&C^(>RHSB?/R\Y0#&C^(>RHSB=/R\Y0#&C^(>RHSB;/R\
MY0#&C^(>RHSB9/R\Y0#&C^(>RHSB7/R\Y0#&C^(>RHSB5/R\Y0#&C^(>RHSB
M3/R\Y0#&C^(>RHSB1/R\Y0#&C^(>RHSB//R\Y0#&C^(>RHSB-/R\Y0#&C^(>
MRHSB+/R\Y0#&C^(>RHSB)/R\Y0#&C^(>RHSB'/R\Y0#&C^(>RHSB%/R\Y0#&
MC^(>RHSB#/R\Y0#&C^(>RHSB!/R\Y0#&C^(>RHSB_/N\Y0#&C^(>RHSB]/N\
MY0#&C^(>RHSB[/N\Y0#&C^(>RHSBY/N\Y0#&C^(>RHSBW/N\Y0#&C^(>RHSB
MU/N\Y0#&C^(>RHSBS/N\Y0#&C^(>RHSBQ/N\Y0#&C^(>RHSBO/N\Y0#&C^(>
MRHSBM/N\Y0#&C^(>RHSBK/N\Y0#&C^(>RHSBI/N\Y0#&C^(>RHSBG/N\Y0#&
MC^(>RHSBE/N\Y0#&C^(>RHSBC/N\Y0#&C^(>RHSBA/N\Y0#&C^(>RHSB?/N\
MY0#&C^(>RHSB=/N\Y0#&C^(>RHSB;/N\Y0#&C^(>RHSB9/N\Y0#&C^(>RHSB
M7/N\Y0#&C^(>RHSB5/N\Y0#&C^(>RHSB3/N\Y5#"G^50,I_E<$`MZ0S`C^`H
MT$WB'`"-Y1@0C>44((WE`S"<YQP`C>(8$(WB%""-XBA"G^4`,)/E)#"-Y0`P
MH./9___K&"*?Y01`C^`4,I_E`B"4YPP@C>4#,)3G`A"@X0,`H.$0,(WEY@P`
MZ_@QG^4#,)3G`$#3Y0``5.-1```*Z#&?Y=T,`.L#,)_G'$"=Y0,@D.<$`(3B
MQC/2Y0<!<.,#,(/C`T"$XL8SPN5C``"*``&@X:?__^NT(9_EM,&?Y1@0G>4"
M((_@`""2Y0S`C^`<4)WE`0!5XP`PH.$$`(SE``"1Y0@@@^6,(9_E``"#Y0(@
MC^`,((/E@"&?Y0(@C^`$((/E3@``V@0`0>(,P(/B!0&`X`3@L>4$X*SE`0!0
MX?O__QH#$(7B``"@XU!1G^4``(WE`0&#YT@1G^4%4(_@!""@X0P`E>4!$(_@
M!O__ZP!`4.(H```*+%&?Y2!@C>(%4(_@#`"5Y4K__^L<`9_E!A"@X0``C^"D
M``#K``!0XR$```H(,9_E`S"/X`P`D^7I_O_K'O__Z_@@G^6X,)_E`B"/X`,P
MDN<`()/E)#"=Y0(@,^``,*#C)0``&@0`H.$HT(WB<("]Z/_^_^O(()_E`B"/
MX```4.,,`(+E&@``"A'__^NT,)_EA`P`ZP,PG^<#,)#G>T?#Y:#__^H,`)7E
MXO[_ZP!`H.'2___J"`"5Y0``4.,!```*/`@`Z]C__^I\`)_E!A"@X0``C^!W
M``#K``!0XP@`A>71__\*]?__ZAK__^L$$*#CMO__Z@$`H.-A___K)/__ZSSJ
M`0`<`0```.H!`/P````4`0``)`$``,SJ`0#PZ@$`\.H!`+PV``"L-@``@.H!
M`!P)``!<Z@$``#0``#3J`0"HZ`$`[.D!`&CI`0#H,@```+"@XP#@H.,$$)WD
M#2"@X00@+>4$`"WE'*"?Y1@PC^(#H(K@`#"@XP0P+>4,`)_E``":YS7__^N8
M_O_K;.<!`"P!```4,)_E%""?Y0,PC^`"()/G``!2XQ[_+P&;_O_J5.<!```!
M```L`)_E+#"?Y0``C^`#,(_@``!3X2`PG^4#,(_@'O\O`1@@G^4",)/G``!3
MXQ[_+P$3_R_AH.@!`)SH`0`@YP$`!`$``#@`G^4X,)_E``"/X`,PC^``,$/@
MHQ^@X4,1@>`D,)_EP1"PX0,PC^`>_R\!&""?Y0(PD^<``%/C'O\O`1/_+^%<
MZ`$`6.@!`-#F`0`(`0``3#"?Y4P@G^4#,(_@`##3Y0(@C^```%/C'O\O$3@P
MG^400"WI`S"2YP``4^,"```**#"?Y0,`G^<$___KRO__ZQPPG^4!(*#C`S"/
MX``@P^40@+WH#.@!`)3F`0`H`0``I.<!`,SG`0#0___JS#"?Y?!'+>D`@%#B
M`S"/X"L```J\()_E`C"3YP"0D^4``%GC*```"@!0V.4!<*#A``!5XST`51,!
M4*`3`%"@`Q$``!H`0)GE``!4XPP```H)8*#A!`"@X04@H.$($*#AQ/[_ZP``
M4.,"```:!3#4YST`4^,+```*!$"VY0``5./S__\:!`"@X?"'O>@(4*#A`3#U
MY0``4^,]`%,3^___&@A01>#F___J"6!&X`%0A>)&8:#A!4"$X`0`H.$`8(?E
M\(>]Z`A`H.'M___J"4"@X>O__^HLY@$`&`$``)`@G^60,)_E`B"/X!!`+>EP
MT$WB`S"2YPT0H.$`0*#A`#"3Y6PPC>4`,*#C?_[_ZP``4.,``*`3!```&A`P
MG>4/.@/B"@I3XP$)4Q,*```*2""?Y4`PG^4"((_@`S"2YP`@D^5L,)WE`B`S
MX``PH.,'```:<-"-XA"`O>@"$*#C!`"@X2'^_^L0#V_AH`*@X>[__^I9_O_K
M5.4!`!P!```$Y0$`8"&?Y6`QG^4"((_@\$`MZ0,PDN=\T$WB`%!0X@`PD^5T
M,(WE`#"@XP(```H`,-7E``!3XPH``!HP(9_E*#&?Y0(@C^`#,)+G`""3Y70P
MG>4"(#/@`#"@XT$``!I\T(WB\("]Z-;]_^L`0%#B\?__"@0`H.%9_O_K``!0
MXRH```H3,-#E$V"`XBX`4^,"```:`3#6Y0``4^/T__\*$S#0Y2X`4^,E```*
M!0"@X?W]_^L`<*#A!@"@X?K]_^L``(?@`@"`XB'^_^ND,)_E`"#@XP,PC^`!
M$*#C!&"-Y0!0C>4`<*#A0/[_ZP@0C>('`*#AX/W_ZP$`<.,'`*#A`P``"A@P
MG>4/.@/B`0E3XQ(```KG_?_K!P"@X<W]_^L$`*#A+O[_ZP``4./4__\:!`"@
MX??]_^L%`*#A$/[_Z[W__^H!,-;E+@!3X];__QH",-;E``!3X\7__PK2___J
MI___Z^O__^K\_?_KL.0!`!P!``!XY`$`4"X``/!!+>D!<*#A`!&?Y0`QG^4!
MVDWB"-!-X@$0C^`#,)'G`&"@X0$*C>($`(#B`#"3Y0`P@.4`,*#CV`"?Y02`
MC>+4()_E``"/X`@0H.$"_O_K`$!0X@<``-H(4(WB`3!$X@/`A>`$(%SE``!2
MXQ<``!H``%/C%```&J`PG^4="P#K`S"?YP<@H.$#`)#G!A"@X87]_^N(()_E
M=#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@,^``,*#C$@``&@':C>((
MT(WB\(&]Z`-`H.$$(*#A+Q"@XP@`H.'V_?_K``!0X^/__PHX,)_E`0L`ZP,P
MG^<((*#A`P"0YP80H.$$,*#AE?W_Z^'__^JT_?_K*.,!`!P!``!L+0``_P\`
M`,SC`0"DX@$`7.,!`/!'+>D`,-'E$"*?Y3T`4^,,,I_E`B"/X`%`H.$#,)+G
M`4"!`@C03>(`4*#A!`"@X0`PD^4$,(WE`#"@XW#]_^L-$*#AW(&?Y0B`C^``
M8*#A!0"@X>#^_^L`D%#B0```"F?]_^L``%;A-P``FK@QG^4`<)WE`X"8YP=Q
MH.$`,-7E``!3XST`4Q,!,*`3`#"@`P4```H%,*#A`2#SY0``4N,]`%(3^___
M&@4P0^`"`(;B`P"`X`!@F.5[_?_K``!0XP<`AN<5```*`""8Y04`H.$!,-#D
M!Q"2YP``4^,]`%,3`##!Y08```H!(('B`3#0Y`(0H.$]`%/C``!3$P$PPN3Y
M__\:/3"@XP$@H.$`,,'E`3#4Y`$PXN4``%/C^___&@@AG^7X,)_E`B"/X`,P
MDN<`()/E!#"=Y0(@,^``,*#C-0``&@C0C>+PA[WH`9!)X@$PU.0!,.GE``!3
MX_O__QKN___JP#"?Y0.`F.<`<)CE`#"7Y0``4^,D```*!S"@X00@L^4)$*#A
M``!2XP&0B>+Z__\:`Q"!X@$1H.&0,)_E`S"/X``@D^4``%+C#P``&@$@H.,!
M`*#A`""#Y3K]_^L`H%#BU?__"@<0H.$)<:#A!R"@X4;]_^L`H(CE`#"@XP"0
MC>4!D(GB"3&*YZ+__^H'`*#A7/W_ZP``4.,`H*#A``"(Y<7__PH)<:#A\O__
MZ@.0H.$($*#CW___ZB7]_^L`X@$`'`$``,SA`0`8`0``[.`!`.CA`0!X$)_E
M>#"?Y3!`+>E@"@#K`1"/X&Q0G^44T$WB`S"1YPPPC>4%4)_G7#"?Y5P0G^4,
M()WE`$"@X0,PC^`%`)#G`1"/X#?]_^M$()_E1#"?Y0(@G^=`$)_E`@"4YSP@
MG^4#,(_@`,"@XP(@C^`!$(_@"!"-Z,[\_^L4T(WB,("]Z,S?`0`0`0``Q.`!
M`"QK```<*@``F.`!`-@L```,*@``4!4``!!`+>DY"@#K.$"?Y3@@G^4$0(_@
M-#"?Y0C03>("()3G!""-Y0,PG^<D$)_E`P"0YR`PG^4!$(_@`S"/X`C0C>(0
M0+WH#OW_ZBC?`0`0`0``(.`!`(0I``"(:@``X""?Y7!`+>G<,)_E`MI-XAC0
M3>("((_@`S"2YP(:C>(4$('B`#"3Y0`P@>4`,*#CZOS_Z[00G^6T,)_E#$"-
MX@$0C^`!:HWBJ""?Y0,PC^`08(;B`P"-Z`$0H.,$`*#AZOS_ZP0`H.$!*J#C
M!A"@X>#\_^L`0%#B&```N@$`A.*[_/_K`%!0XA0```H$(*#A!A"@X9+\_^L`
M,*#C!##%YU0@G^5`,)_E`B"/X`(:C>(#,)+G%!"!X@`@D^4`,)'E`B`SX``P
MH.,#```:!0"@X0+:C>(8T(WB<("]Z*?\_^L`4*#C[?__ZLC>`0`<`0``7"D`
M`$0I```!$```--X!`+[__^I((I_E\$\MZ40RG^5"W4WB!-!-X@(@C^``8*#A
M-`*?Y0,PDN=!S8WB$("-X@%`H.$``(_@"!"@X3S`C.(`,)/E`#",Y0`PH./4
M_?_K+Q"@XP!0H.$&`*#A+?S_ZP``4.,2```*\`&?Y080H.$``(_@T_[_ZP8`
MH.'@(9_ET#&?Y0(@C^!!'8WB`S"2YSP0@>(`()/E`#"1Y0(@,^``,*#C:0``
M&D+=C>($T(WB\(^]Z`0`H.%D_/_KI!&?Y0$0C^!S_/_K`$!0XN7__PH`,-3E
MD)&?Y8"@C>(``%/C"9"/X`1P2N([```*``!5XP0```H$$*#A!0"@X9C\_^L`
M`%#C*P``"@0`H.$N_/_K`3!`X@,PA.`#`%3A`+"@X0`PA#``$*`S`0"$,@,`
M`#H(``#J`P!0X0`0P^4"```*`2!SY2\`4N/Y__\*!`"@X1W\_^L`L*#A!@"@
MX1K\_^L+`(#@`0"`X@$*4..]__\J^`"?Y0DPH.$``(_@`2J@XP$0H.-!`(WI
M`$"-Y0<`H.%>_/_K"!"@X0<`H.'^^__K``!0XP,``!I@,!KE#SH#X@()4^,5
M```*M!"?Y0``H.,!$(_@,_S_ZP!`4.*E__\*`##4Y0``4^/#__\:``!5XQ8`
M``H`,-7E+@!3XP,```J`0)_E`;"@XP1`C^#5___J`3#5Y0``4^/J__\*]___
MZ@$0H.,'`*#AW/O_ZP``4./D__\:4`"?Y0<0H.$``(_@9/[_ZP<`H.$$_/_K
MCO__ZCA`G^4!L*#C!$"/X,'__^H*_/_KQ-T!`!P!``!P*```0"@``%C=`0``
M*```Y"<``%0G````)P``J"8``(0F``!8)@``$$`MZ2\0H.,`0*#AK_O_ZP``
M4.,!0(`2!`"@X1!`O>CI^__J="&?Y7!`+>EP,9_E`=I-X@(@C^`(T$WB`1J-
MX@,PDN<`8%#B!!"!X@`PD^4`,('E`#"@XR\```H`,-;E``!3XRP```JV^__K
M`2"`X@$*4N,`0*#A.```B@10C>(&$*#A!0"@X;3[_^L!,$3B`S"%X`4`4^$'
M``":`!"@XP(``.H%`%/A`1##Y0(```H!(%/D+P!2X_G__PHO$*#C!0"@X8'[
M_^L``%#C)0``"@4`4.$`,*"#`##`A04`H.&Y^__KO""?Y;0PG^4"((_@`1J-
MX@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@XR(``!H!VHWB"-"-XG"`O>B(()_E
M?#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@,^``,*#C%```&F``G^4`
M`(_@`=J-X@C0C>)P0+WHFOO_Z@``H./>___J1""?Y3`PG^4"((_@`1J-X@,P
MDN<$$('B`""3Y0`PD>4"(#/@`#"@XR``GP4``(\`[/__"I;[_^LDVP$`'`$`
M`&S:`0`TV@$`T"0``.C9`0"()```R"2?Y<@TG^4"((_@<$`MZ<!DG^4#,)+G
M"-!-XKA4G^4&8(_@#4"@X0`PD^4$,(WE`#"@XP50C^`$$*#A!@"@X<?\_^L`
M`%#C#@``"HPTG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P
M@^($()/E!""#Y```4N/[__\:Z___ZE1DG^4&8(_@!!"@X08`H.&Q_/_K``!0
MXPX```HT-)_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B
M!""3Y00@@^0``%+C^___&NO__^H`9)_E!F"/X`00H.$&`*#AF_S_ZP``4.,.
M```*W#.?Y0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@
MD^4$((/D``!2X_O__QKK___JK&.?Y09@C^`$$*#A!@"@X87\_^L``%#C#@``
M"H0SG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E
M!""#Y```4N/[__\:Z___ZEACG^4&8(_@!!"@X08`H.%O_/_K``!0XPX```HL
M,Y_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@
M@^0``%+C^___&NO__^H$8Y_E!F"/X`00H.$&`*#A6?S_ZP``4.,.```*U#*?
MY0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D
M``!2X_O__QKK___JL&*?Y09@C^`$$*#A!@"@X4/\_^L``%#C#@``"GPRG^4`
M`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```
M4N/[__\:Z___ZEQBG^4&8(_@!!"@X08`H.$M_/_K``!0XPX```HD,I_E``"=
MY0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C
M^___&NO__^H(8I_E!F"/X`00H.$&`*#A%_S_ZP``4.,.```*S#&?Y0``G>4#
M,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O_
M_QKK___JM&&?Y09@C^`$$*#A!@"@X0'\_^L``%#C#@``"G0QG^4``)WE`S"5
MYP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```4N/[__\:
MZ___ZF!AG^4&8(_@!!"@X08`H.'K^__K``!0XPX```H<,9_E``"=Y0,PE><`
M$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___&NO_
M_^H,`9_E!!"@X0``C^#6^__K`!!0X@(```KX`)_E``"/X-K\_^OP`)_E!!"@
MX0``C^#-^__K`!!0X@(```K<`)_E``"/X-'\_^O4`)_E!!"@X0``C^#$^__K
M`!!0XA(```K``)_E``"/X,C\_^NX()_E9#"?Y0(@C^`#,)+G`""3Y00PG>4"
M(#/@`#"@XQ```!J8$)_EF`"?Y0$0C^```(_@"-"-XG!`O>BX_/_JA`"?Y000
MH.$``(_@J_O_ZP`04.+I__\*<`"?Y0``C^"O_/_KY?__ZEOZ_^N4V0$`'`$`
M`'`D``!HV0$`&`$``!`D``#`(P``=",``"0C``#<(@``("(``#@B``#L(0``
MH"$``,P@``#X(```S"```.@@``#H(```Y"````@@```PU0$`P"```"0@``"0
M(```%"```)PPG^6<$)_EG""?Y0,PC^`$X"WE`1"/X```D^4"()'G#-!-X@$`
M<.,`()+E!""-Y0`@H.,*```*<""?Y6@PG^4"((_@`S"2YP`@D^4$,)WE`B`S
MX``PH.,0```:#-"-X@3PG>1(`)_E#1"@X0``C^!M^__K``!0XP0```H``-#E
M,`!0XP``4!,!`*`3``"@`R`PG^4#,(_@``"#Y>7__^H8^O_KD-4!`%#4`0`<
M`0``)-0!`#`?```(U0$`$$`MZ<OY_^OK^?_K``!0XP``D!40@+WH/"&?Y?!`
M+>DX,9_E.&&?Y0(@C^`<T$WB`S"2YP9@C^``4*#A$!"-X@8`H.$`,)/E%#"-
MY0`PH.-&^__K`$!0X@(```H`,-3E``!3XPX``!KX()_E[#"?Y0(@C^`#,)+G
M`""3Y10PG>4"(#/@`#"@XS(``!K8`)_E!1"@X0``C^`<T(WB\$"]Z#O\_^H%
M$*#AS/G_ZP``4.,*```*M""?Y:`PG^4"((_@`S"2YP`@D^44,)WE`B`SX``P
MH.,?```:'-"-XO"`O>@%`*#AJ_G_ZP!PH.$$`*#AJ/G_ZP``A^`"`(#BS_G_
MZVP@G^5L,)_E`B"/X`,PC^`!$*#C"$"-Y00@C>4`4(WE`"#@XP!`H.'K^?_K
M2""?Y2@PG^4"((_@`S"2YP`@D^44,)WE`B`SX``PH.,$$*`!!@"@`<___PJ[
M^?_K@-,!`!P!```L'P``.-,!`,P>``#LT@$`A!T``(0=``!TT@$`<!>?Y?!/
M+>EL)Y_E`ME-XOS03>(!$(_@8#>?Y0(@D><`<*#A`@F-X@,PC^``()+E]""`
MY0`@H./T`(#B!P"3Z?A@C>)TH$;B$."#XBB0@^('`(KH#P"^Z%S`1N(/`*SH
M`P">Z&A`1N(#`(SH!P"9Z`<`A.@(!Y_EX%!&X@40H.$``(_@V?K_Z_B&G^4(
M@(_@`$!0X@(```H`,-3E``!3XPL!`!I#^?_K8_G_ZP``4./J```*`*"0Y0``
M6N/G```*"@"@X5/Y_^N``*#A`0"`XGKY_^L`,-KE``!3XP!`H.$`D*#A"P``
M"IRVG^4+L(_@!`"@X0`PC>4`(.#C"S"@X0$0H..4^?_K`3#ZY0)`A.(``%/C
M]?__&G`&G^5<H$;B``"/X`(``.H$`+KE``!0XPT```H%$*#AK/K_ZP!`4.+X
M__\*`##4Y0``4^/U__\*W?K_ZP``4./R__\*!`"@X4WY_^L`0%#B#@``&G2@
M1N($0)KD``!4XPH```H`,-3E``!3X[,```H$`*#ASOK_ZP``4./U__\*!`"@
MX3[Y_^L`0%#B\?__"@0`H.$9^?_K`*"@X0D`H.$6^?_K`*"*X`&KBN($H(KB
M"@"@X3OY_^N\-9_E`"#@XP,PC^`(,(WEL#6?Y0$0H.,#,(_@!#"-Y:0UG^4,
MD(WE`S"/X`!`C>4`L*#A5/G_ZP<=H.,+`*#AOOC_ZP$`<.,#```::?G_ZP`0
MD.41`%'CG@``&@40H.$+`*#A,/G_ZP"04.(8```*6"6?Y0`PE^4"$)CG4"6?
MY0``D>4"((_@`1"@XP"PC>4<^?_K`("@XS@EG^4(-9_E`B"/X`(9C>(#,)+G
M]!"!X@`@D^4`,)'E`B`SX``PH.,W`0`:"`"@X0+9C>+\T(WB\(^]Z-`P%N4/
M.@/B`0E3X^+__QK(0!;EOOC_ZP``5.'>__\:T#`6Y8,[H.&C.Z#A!PU3X]G_
M_QH*`*#A]_C_ZP40H.$`@*#AO`2?Y0``C^`^^O_K`!!0XHX```H``)?E4OS_
MZP"@4.**```*"@"@X<#X_^L#`%#C`$"@X0P``)J(%)_E!`!`X@``BN`!$(_@
M'OG_ZP``4.,%```:!`!4X]@```H$0(K@!3!4Y2\`4^/4```*6$2?Y01`C^``
M,)3E`0!SX\$```H``%/C<P``"D`4G^5`!)_E`1"/X```C^`C^__KZ/C_ZS`T
MG^4P=)_E`S"/X`PPC>4H-)_E*&2?Y0,PC^`$,(WE(#2?Y2!4G^4#,(_@`"#@
MXP$0H.,`L(WE!W"/X`9@C^`%4(_@"`"-Y0@`H.'@^/_K#P``ZOGX_^L`,)#E
M$0!3XQ$``!K.^/_K`9")X@<PH.$$(*#A`1"@XQ!@C>4,D(WE`+"-Y0#`H.$@
M$(WI"`"@X<_X_^L'':#C"`"@X3GX_^L!`'#C`$"@X>G__PH+`*#A8?C_ZY0#
MG^4($*#A``"/X/'Z_^L(`*#AD/[_ZX/__^H#0*#A4?__ZFA`1N($`)3D``!0
MXRD```H%$*#AW?G_ZP`P4.+X__\*`##3Y0``4^/U__\*@OC_ZP"@4.+R__\*
M7OC_ZX``H.$!`(#B"?__ZO`BG^4`,)?E`@"8YR`CG^4``)#E`B"/X`00C>4`
ML(WE`1"@XX'X_^MC___J;_[_ZP`CG^68,I_E`B"/X`(9C>(#,)+G]!"!X@`@
MD^4`,)'E`B`SX``PH..;```:!`"@X0+9C>+\T(WB\$^]Z&#X_^H-`*#C9_C_
MZ[RBG^53,*#C"J"/X`!`H.$`D*#AZ_[_Z@"@E^5R___J"@"@X0`0H.-!^/_K
M`$!0XH;__PH"4*#C`##@XQ$@X.,$<$;B`%"-Y5'X_^L&(*#C!Q"@X00`H.$4
M^/_K!#!6Y0``4^,"```:`S!6Y4,`4^-3```*`#"@XP`@H.,`,(WE!`"@X0`P
MH.-!^/_KR`0`ZP!0H.$"``#J!Q"@X04`H.'F!`#K`BF@XP<0H.$$`*#A_O?_
MZP`@4.+V___*!`"@X41`1N(@^/_K!1"@X00`H.$@!0#K[)&?Y3!P1N()D(_@
M!U"@X0$0U.0%`*#A`!"-Y0DPH.$`(.#C`1"@XT[X_^L$`%?A`E"%XO7__QJX
M,9_E`""@XP,PC^`$,(WE"'"-Y0"PC>4(($;EH"&?Y:`QG^4"((_@#""-Y0,P
MC^``(.#C`1"@XP@`H.$[^/_K</__ZH`!G^4%$*#A``"/X%OY_^L``%#C``"$
M!:S__PH`,-#E``!3XS``4Q,!,*`3`#"@`P`PA.4O___J!$"7Y0``5.,G__\*
M!`"@X=;W_^L#`%#C(___FC`1G^4$`$#B``"$X`$0C^`U^/_K``!0XP2@H`$;
M___J`C!6Y4$`4^.H__\:`3!6Y4,`4^.E__\:`##6Y4@`4^.B__\:`3#6Y44`
M4^.?__\:`##@XSD@X.,$`*#A`%"-Y>+W_^L'$*#A*2"@XP0`H.&E]__KP#"?
MY<`0G^4#,(_@##"-Y;@PG^4!$(_@!!"-Y0,PC^``(.#C`1"@XP@`H.$(<(WE
M`+"-Y?KW_^LO___JU/?_ZQ32`0`<`0``.-,!`'`<``"<T0$`#!T``(P<```T
M'```,!L```@<```@`0``_!L``+C/`0"X&P``@!L```C0`0!D&@``Y!D``/0;
M```<&P``>!D``,`;```<&P``4!D``*P8``!8&0``2,T!`,@8``#\%P``Y!8`
M`#09``!D&```Z!8``.07``!$&```S!4``&@7``!\$I_E?"*?Y0$0C^!P0"WI
M[P0`ZP(@D><(T$WB:#*?Y0`@DN4$((WE`""@XP,PG^<-4*#A`T"0YU`"G^5H
M,-3E``"/X`40H.%I,,3EY/C_ZP``4.,"```*`##0Y3$`4^-M```*!?S_ZR0R
MG^78!`#K`S"?YP-`D.<8$I_E!`"@X0$0C^`#,*#C`2"@XS?W_^L`0%#B#@``
M"A`@E.7X,9_E`!"2Y0,PG^?P(9_ER`0`ZP(@C^``8*#A`P"0YS'W_^L0,)3E
M`!"3Y0@PD>4!!1/C70``&L@QG^7($9_E`S"?Y[L$`.L!(*#C`&"@X0$0C^`#
M`)#G`S"@XQSW_^L`0%#B"P``"J`!G^4%$*#A``"/X+/X_^L`(%#B0P``"HPQ
MG^40$)3E`S"?YP`0D>4#`);G%/?_ZW@QG^6E!`#K`S"?YW`1G^4#8)#G`$"@
MX0$0C^`!(*#C!@"@X?7V_^M8(9_E`B"/X``0H.$&`*#A!??_ZT@QG^5(`9_E
M`S"?YP`@H.,#,)3G!1"@X0``C^!I(,/ED_C_ZRQ1G^4%4(_@``!0XP!`H.$(
M`(7E$@``"@<=H.,$`*#ATO;_ZP$@@.(1`%#C`0!2$P`PH.$E``"*^""?Y;`P
MG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,;```:"-"-XG"`O>@$`)7E?/W_
MZP``4.,`0*#A"`"%Y>;__QJX`)_E``"/X#WW_^L!,-#E``!3XY/__PJ-___J
MH#"?Y1`@E.4#,(_@!#"3Y0``DN4`$)/E)/G_Z[G__^J$,)_E`S"?YP,`EN</
M]__KG/__ZA;W_^MP()_E<`"?Y0(@C^`$()+E``"/X``0DN4$(*#A(_?_ZQ3*
M`0`<`0``_,H!`/@4``"XR@$`9!8``(3*`0`X%@``3,H!``06``#D$P``!,H!
M`.S)`0"H%0``K!4``+#)`0!<$P``^,D!`$C(`0``%0``7,D!`-C(`0`DR0$`
MQ!0``#PAG^4\,9_E`B"/X/!`+>D#,)+G#-!-X@`PD^4$,(WE`#"@XP!0H.'U
M^O_K+Q"@XQ1QG^4'<(_@`$"@X9OV_^L``%#C`4"`$@0`H.'6]O_K`#"7Y0!`
M5>(!0*`3`0!SXP!@H.$F```*``!3XP!`H`,!0`02``!4XPH``!K,()_EP#"?
MY0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XR<``!H,T(WB\("]Z``PU>4``%/C
M\?__"I@0G^4$(*#C`1"/X`8`H.'K]O_K``!0X^K__QJ`()_E;#"?Y0(@C^`#
M,)+G`""3Y00PG>4"(#/@`#"@XQ(``!H%`*#A#-"-XO!`O>A>^/_J4`"?Y0T0
MH.$``(_@^O?_ZP``4.,``(<%UO__"@`PT.4``%/C,`!3$P$PH!,`,*`#`T`$
MX``PA^7,___JI?;_ZS#'`0`<`0``/,@!`+3&`0!@$@``8,8!`&01``#P3RWI
M7.R?Y5P\G^4.X(_@I]]-X@,PGN<0((WB`!"@X4#`@.*`4(#B`#"3Y90RC>4`
M,*#C`@"@X0!`H.,$8!SE"'`<Y28TH.%GZ"?@_SP#XB8\@^$NY*#A!H2@X08\
M@^'_[,[C_V@(X@C`C.)GY"[@!C"#X04`7.$`X(#E!$"`Y0@P@.4,0(#E$`"`
MXNK__QJ"/X+B!#"-Y8@PG>48X(WB'*"=Y0@0C>5X@)WE?""=Y1BPG>6`<)WE
MA&"=Y8S`G>404)WE%$"=Y0X`H.$#$*#A#."-Y0"@C>4!``#J";"@X0`PC>4!
M,*#A/."0Y3@0D.4(D+#E`*"@XPD0(>`($"'@!X"@X0-PH.$$,)#E!1`AX`/@
M+N`"X"[@!.`NX`8@H.$,8*#AH<^@X8[`C.$!$)'@#!"!X03`G>4`0)WE``!<
MX0M0H.$*P*#A=*"`Y7`0@.7A__\:"!"=Y0S@G>4`@)'E"#N?Y0$(D>D((![E
M($"1Y:AMH.$0<)'E&)"1Y0,@DN"`8H;A!""2X(ABAN$,P)'E`F"6X`D@)^`K
M4:#A"R`"X`D@(N`,7X7A`F"6X`M?A>$8()WE*,&@X0#/C.$%`"?@`R"2X`@`
M`.`)()+@!P`@X`C/C.$``)+@""">Y0Q`)>`#()+@!D`$X`5`).`'()+@Y@V`
MX`0@DN#@38+@$"">Y0,@DN`%()+@9E$LX`!0!>`,4"7@!2"2X!A0GN5@`:#A
M`U"5X`S`E>!F42#@!%`%X&91)>#D+8+@!<"<X.)=C.`@P)[E`\"<X&;!C.!D
M82#@`F`&X`!@)N`&P)S@*&">Y6(AH.$#8);@``"6X&1A(N`%8`;@9&$FX.7-
MC.`&`)#@[&V`X#``GN4#`)#@9`&`X&5!(N`,0`3@`D`DX`0`D.`X0)[E;,&@
MX0-`E.`"()3@94$LX`9`!.!E023@Y@V`X`0@DN#@38+@0"">Y0,@DN!E(8+@
M9E$LX`!0!>`,4"7@!2"2X$A0GN5@`:#A`U"5X`S`E>!F42#@!%`%X&91)>#D
M+8+@!<"<X.)=C.!0P)[E`\"<X&;!C.!D82#@`F`&X`!@)N`&P)S@6&">Y6(A
MH.$#8);@``"6X&1A(N`%8`;@9&$FX.7-C.`&`)#@[&V`X&``GN4#`)#@9`&`
MX&5!(N`,0`3@`D`DX`0`D.!H0)[E;,&@X0-`E.`"()3@94$LX`9`!.!E023@
MY@V`X`0@DN#@38+@<"">Y0,@DN!E(8+@9E$LX`!0!>`,4"7@!2"2X'A0GN5@
M`:#A`U"5X`S`E>!F42#@!%`%X&91)>#D+8+@!<"<X.)=C."`P)[E`\"<X&;!
MC.!D82#@`F`&X`!@)N`&P)S@Y6V,X(C`GN5B(:#A`\"<X```G.!DP2+@!<`,
MX&3!+.`,`)#@YLV`X)``GN4#,)#@90$BX`8``.`"`"#@9#&#X``PD^#LK8/@
MF`">Y2PXG^5F8:#A`P"0X*!`GN4"()#@90$FX`P`(.``()+@`P"4X&4!@.#J
M38+@J%">Y6PA)N`*("+@`@"0X&HAH.$#4)7@L*">Y090E>!L82+@!&`FX.0-
M@.`&4)7@`V":X&QAAN"XH)[EX,V%X&11(N``4"7@!6"6X&`!H.$#4)K@`E"5
MX,"@GN7L+8;@9&$@X`Q@)N`&4)7@`V":X&1AAN#(H)[E;$$@X`)`).#B787@
M!&"6X&(AH.$#0)K@``"4X-"@GN5L02+@!4`DX`1`D.`#`)K@Y6V&X-B@GN5L
M`8#@9<$BX`;`+.#F383@#`"0X&9AH.$#P)K@`B"<X."@GN5EP2;@!,`LX`S`
MDN`#()K@Y`V`X.B@GN5E(8+@9%$FX`!0)>#@S8S@!2"2X&`!H.$#4)K@!E"5
MX/B@GN7P8)[E9.$@X`S@+N#L+8+@#N"5X.)=CN`#8);@;.$@X&1!AN`"X"[@
M#N"4X&(AH.$#0)K@`$"4X!AAG>5L`2+@!0`@X.7MCN```)3@`V"6X.Y-@.!L
MP8;@90$BX"!AG>4.`"#@``"<X&[AH.$#8);@`B"6X&7!+N`H89WE!,`LX.0-
M@.`,P)+@`R"6X&4A@N`P89WEX%V,X&3!+N``P"S@#,"2X&`!H.$#8);@Y2V,
MX`[@EN!DP2#@.&&=Y07`+.`,P)[@`^"6X&3ACN!`89WE94$@X`)`).#BS8S@
M!.">X&(AH.$#8);@``"6X&5!(N!(89WE#$`DX.SMCN!0H9WE!$"0X`,`EN#L
M-9_E;&$BX&4!@.`.8";@;E&@X>Y-A.`&8)#@;.&%X0,`FN`"`)#@6*&=Y>0M
MAN`$X`[@;&$%X`;@CN$.X)#@`Z":X&0!A>%D807@;,&*X`(``.!@H9WE!@"`
MX>+MCN`,`)#@8B&@X0/`FN`%P)S@9%&"X61A`N!HH9WE#E`%X`90A>'N#8#@
M#%"5X`.@FN!NP8+A;F$"X&1!BN``P`S@<*&=Y0;`C.'@787@!$"<X&`!H.$#
MP)K@`L"<X.4MA.!N08#A;F$`X'BAG>4%0`3@!D"$X0Q`E.`#H)K@9<&`X65A
M`.!NX8K@`L`,X("AG>4&P(SAXDV$X`[@G.!B(:#A`\":X`#`G.#D#8[@9>&"
MX65A`N"(H9WE!.`.X`;@CN$,X)[@`Z":X&3!@N%D80+@95&*X`#`#."0H9WE
M!L",X>#MCN`%4)S@8`&@X0/`FN`"P)S@[BV%X&11@.%D80#@F*&=Y0Y0!>`&
M4(7A#%"5X`.@FN!NP8#A;F$`X&1!BN`"P`S@H*&=Y0;`C.'B787@!$"<X&(A
MH.$#P)K@`,"<X.4-A.!N08+A;F$"X*BAG>4%0`3@!D"$X0Q`E.`#H)K@9<&"
MX65A`N!NX8K@`,`,X+"AG>4&P(SAX$V$X`[@G.!@`:#A`\":X`+`G.#D+8[@
M9>&`X65A`."XH9WE!.`.X`;@CN$,X)[@`Z":X&3!@.%D80#@95&*X`+`#.#`
MH9WE!L",X>+MCN`%4)S@8B&@X0/`FN``P)S@[@V%X&11@N'(H9WE9&$"X`Y0
M!>`&4(7A#%"5X`.@FN!NP8+A;F$"X&1!BN``P`S@T*&=Y0;`C.'@787@!$"<
MX&`!H.$#P)K@`&"@XP+`G.#E+83@;D&`X05`!.`$8('E#&"!Y11@@>4<8('E
M;F$`X-BAG>4&0(3A#$"4X&7!@.$#H)K@96$`X`+`#.!NX8K@!L",X>"AG>7B
M383@#L"<X&(AH.'D[8S@`Z":X&7!@N%E80+@``":X`3`#.#HH9WE!L",X0#`
MG.`#H)K@9`&"X>@RG^5D80+@95&*X`X``.#PH9WE!@"`X>[-C.`%`)#@;N&@
MX0-0FN`"4)7@^&&=Y60A+N`,("+@[`V`X`(@E>`#8);@X%V"X&1!AN!L(2[@
M`&*=Y0`@(N`"()3@8`&@X0-`EN`.0)3@"&*=Y6SA(.`%X"[@#N"4X`-`EN#E
M+8+@$&*=Y6Q!A.!EP2#@`L`LX.+MCN`,P)3@8B&@X0-`EN``0)3@&&*=Y64!
M(N`.`"#@[LV,X```E.`#0);@94&$X"!BG>7L78#@;@$BX`P`(.```)3@;,&@
MX0-`EN`"0)3@*&*=Y6XA+.`%("+@Y0V`X`(@E.`#8);@X$V"X&[AAN!E(2S@
M,&*=Y0`@(N`"()[@8`&@X0/@EN`,X)[@.&*=Y67!(.`$P"S@Y"V"X`S`GN`#
MX);@9>&.X$!BG>7B78S@9,$@X`+`+.`,P)[@8B&@X0/@EN``X)[@2&*=Y60!
M(N`%`"#@Y<V,X```GN`#X);@9.&.X%!BG>7L38#@90$BX`P`(.```)[@;,&@
MX0/@EN`"X)[@6&*=Y64A+.`$("+@Y`V`X`(@GN`#X);@9>&.X&!BG>7@78+@
M9"$LX``@(N`"()[@8`&@X0/@EN`,X)[@:&*=Y63!(.`%P"S@Y2V"X`S`GN`#
MX);@9.&.X'!BG>7B38S@9<$@X`+`+.`,P)[@8B&@X0/@EN``X)[@>&*=Y64!
M(N`$`"#@``">X`/@EN#DS8S@9>&.X&1A(N"`4IWE#&`FX.P-@.`&X)[@;,&@
MX0-0E>`"()7@9&$LX(A2G>4`8";@!B"2X`,PE>#@[8[@8)&)X`@PD^!@`2S@
M#@`@X&0Q@^``,)/@[BV"X.(]@^!N<8?@"R"2X"``D>48D('E$'"!Y0`P@>4(
M(('E4""?Y3@PG^4"((_@`,"<X`!@H.,@P('E)&"!Y0,PDN<`()/EE#*=Y0(@
M,^``,*#C`0``&J??C>+PC[WHA//_Z\S%`0`<`0``F7F"6J'KV6[<O!N/UL%B
MRJBY`0!P0"WI@`"@XW?S_^M04(_BT$#%X0`@H./P0,#A2%"/XM!`Q>%X((#E
M^$#`X4!0C^+00,7A\$'`X3Q0C^+00,7A^$'`X3A0C^+00,7A\$+`X0!`H.,`
M4*#C^$+`X?!#P.%P@+WH`2-%9P````")J\WO`````/[<NI@`````=E0R$```
M``#PX=+#`````/!'+>DH,)#E`F"@X8;!@^`L()#E`P!<X0`PH.,"(-/@`%"@
MX3`@D.4!0*#A-!"0Y<8/H.$!```J`2"2X@`0H>(L,(7EICZ@X8`Q@^$",)/@
MH!ZAX'@`E>4X@(7B``!0XRC`A>4P,(7E-!"%Y18``!H_`%;C)0``VD!@1N(F
MDZ#A`7")X@=SA.`$$*#A0""@XP@`H.$-\__K0$"$X@4`H.&2_/_K!P!4X?;_
M_QH)G6G@"6.&X`8@H.$'$*#A"`"@X0+S_^MX8(7E\(>]Z$!P8.(&`%?A!G"@
MH0``B.`'(*#A!!"@X?GR_^MX,)7E`S"'X$``4^-X,(7E\(>]&`4`H.$'8$;@
M!T"$X'C\_^O7___J!'"@X>;__^KP02WI*#"1Y0%`H.%C*"/@,!"1Y2(DH.'_
M+,+C8W0BX&$H(>"C,:#A(B2@X3\P`^+_+,+C860BX`$@@^(X@(3B?Q#@XS@`
M4N,`4*#A`Q#(YP(`B.`\``#:0"!BX@`0H..J\O_K!`"@X5K\_^L(`*#A.""@
MXP`0H..D\O_K!`"@X7!@A.5T<(3E4OS_ZP,PU.4`,,7ELC#4X0$PQ>4`,)3E
M!`"@X2,TH.$",,7E`#"4Y0,PQ>4+,-3E!##%Y;HPU.$%,,7E"#"4Y2,TH.$&
M,,7E"#"4Y0<PQ>43,-3E"##%Y;(QU.$),,7E$#"4Y2,TH.$*,,7E$#"4Y0LP
MQ>4;,-3E###%Y;HQU.$-,,7E&#"4Y2,TH.$.,,7E&#"4Y0\PQ>4C,-3E$##%
MY;(RU.$1,,7E(#"4Y2,TH.$2,,7E(#"4Y1,PQ>7P0;WH?_+_ZC@@8N(`$*#C
M;?+_Z\?__^H````````````````/"N#C'_!`X@@PG^4#,(_@`#"3Y<;R_^IP
MMP$`"$`MZ0B`O>@!``(`/0```$`````+````0````!````!`````)@```$``
M```U````0`````,```!`````!@```$`````4````0`````X```!`````#0``
M`$`````E````0````!(```!`````*````$`````"````0````!@```!`````
M"0```$`````*````0```````````````)7,O)7,````O<')O8R]S96QF+V5X
M90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2
M.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%35``````4$%2
M7U!23T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)0@````!015),
M3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]3
M4$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!
M4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?5$U0
M1$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@`````Q````
M3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>``````E<R5S)7,E<P````!P
M87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO
M=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R`````"5S)7-C
M86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``
M```8````<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP
M-38```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*`````"UE```M+0``55-%4@````!54T523D%-10``
M``!414U01$E2`%1-4``O=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1&24Q%7V]F9G-E=%]S:7IE+"`D0T%#2$5?;6%R:V5R+"`D8V%C:&5?;F%M
M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD
M1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VUA
M<FME<B`](")<,$-!0TA%(CL*)&-A8VAE7VYA;65?<VEZ92`](#0P.PI]"G-U
M8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S
M:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*
M;7D@)'!O<R`]("1S:7IE("T@)'-I>F4@)2`D8VAU;FM?<VEZ93L@("`@("`C
M($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL
M92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@
M)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H
M;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)'!O
M<R`K/2`D:3L*<F5T=7)N("1P;W,["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*
M?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@
M9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H
M*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D[
M"G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@
M)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P*
M*3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@
M/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I
M;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE
M.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y
M<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S
M<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)
M3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N
M86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;
M7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*
M;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D[
M"FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI-04=)0SH@>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ
M<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I
M;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@
M<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S
M(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@
M>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#
M(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B
M1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A
M9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@
M=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F
M($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D
M1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1D871A7W!O<R`]('1E
M;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@
M("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&
M24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U
M;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN
M86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<
M9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT
M*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(
M+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX
M?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B
M+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA
M;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE
M;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>
M+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D
M9FEL96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W
M-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)$UO
M9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@
M)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U
M;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@
M/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@
M<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A
M8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E
M<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I
M;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2([
M"B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F
M:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N
M86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F
M?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G
M/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE
M;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@
M9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4[
M"G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI
M<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M
M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI
M('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U
M;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*
M9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IU;FQE<W,@*"1B
M=68@97$@(E!+7#`P,UPP,#0B*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F
M=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@
M34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@
M("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D
M;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%
M3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A
M('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;
M,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C
M;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@
M=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*
M:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@
M0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE
M;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,[
M"G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU
M<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D
M9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E
M("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I
M9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q
M(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q
M)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D
M;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE
M("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE
M(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M
M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D[
M"G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N
M;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'
M5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II
M9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF
M="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M
M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R
M(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO
M<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]
M"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@
M)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP
M87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@
M*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A
M9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B
M=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S
M<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T95!A
M=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ
M1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ
M1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A
M=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(
M+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I('L*
M<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C86P@
M)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"FEF("@D;65T85]P87)[
M8VQE86Y]*2!["FUY("1P87)?8VQE86X@/2`B/3$B.PIM>2`D<&%S<U]P87)?
M8VQE86X@/2!U8R`B7U]P87-S7W!A<E]C;&5A;E]?(CL*)&QO861E<B`]?B!S
M>R@_/#TD>W!A<W-?<&%R7V-L96%N?2DH("LI?0I[)'!A<E]C;&5A;B`N("@B
M("(@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<&%R7V-L96%N*2DI?65G.PI]
M"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\
M9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]
M*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S
M("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E
M;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D
M9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y
M+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@
M*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E
M<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[
M)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II
M9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q
M(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D
M9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS
M<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@
M)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F
M*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*
M;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@
M/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD[
M"E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL
M"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D
M(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II
M<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@
M;V8@(B1O=70B73L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M
M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*:68@*"$D8V%C:&5?;F%M92!A;F0@
M;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E
M<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1T:"P@(CPZ<F%W(BP@)&]U=#L*
M)&-T>"T^861D9FEL92@D=&@I.PIC;&]S92`D=&@["B1C86-H95]N86UE(#T@
M)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H)&-A
M8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N
M86UE("X]("1C86-H95]M87)K97(["FUY("1O9F9S970@/2`D9F@M/G1E;&P@
M*R!L96YG=&@H)&-A8VAE7VYA;64I("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M
M/G!R:6YT*"1C86-H95]N86UE+`IP86-K*"=.)RP@)&]F9G-E="DL"B1005)?
M34%'24,I"B8F("1F:"T^8VQO<V4*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI
M=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P
M<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N
M(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@
M;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z
M.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA
M;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R
M(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI:
M:7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A
M8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*
M;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB
M97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI]
M(&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M
M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D
M:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N
M86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U
M>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI
M8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@
M<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R
M"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF
M="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H
M+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G
M7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A
M=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET
M:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*
M<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@
M<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I
M<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E
M<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q
M=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O
M;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$
M:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I
M<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R
M97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!]
M.PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A
M;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![
M(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V
M86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H
M(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U0
M1$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@
M*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@
M86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![
M*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H
M(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F
M5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*
M)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6
M>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S
M=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L
M("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?
M9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M
M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@
M*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@
M>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@
M;&5N9W1H*"1C86-H95]M87)K97(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@
M)&)U9BP@;&5N9W1H*"1C86-H95]M87)K97(I.PII9B`H)&)U9B!E<2`D8V%C
M:&5?;6%R:V5R*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F
M<V5T7W-I>F4*+2!L96YG=&@H)&-A8VAE7VUA<FME<BD*+2`D8V%C:&5?;F%M
M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*
M)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]
M"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER
M(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER
M("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A
M<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C
M;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E
M;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA
M;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A
M=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC
M;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B
M.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D
M93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E
M;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N
M86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6
M>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]
M"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD
M97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA
M;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES
M>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@
M:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P
M96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H
M.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE
M("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H
M<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X
M="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM0
M05)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P
M<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE
M?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S
M>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N
M86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@
M?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@
M)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI
M;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D
M)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,
M25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.
M251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.
M($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?
M)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2![
M"B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X
M:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%
M35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R![
M"G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H
M(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?
M:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D
M+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I
M=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@
M=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*
M=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P
M87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I
M<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*
M=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET
M*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@
M:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET
M*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*````
M`'!E<FQX<VDN8P```#T```!`````"P```$`````0````0````"8```!`````
M-0```$`````#````0`````8```!`````%````$`````.````0`````T```!`
M````)0```$`````2````0````"@```!``````@```$`````8````0`````D`
M``!`````"@```$```````````````#2,_W\!````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(P8```D&````0````D#```!````
M&0,```$````C`P``#````)`1```-````G$@``!D```#`_0$`&P````0````:
M````Q/T!`!P````$````]?[_;ZP!```%````%`D```8```"4`@``"@```)L$
M```+````$````!4``````````P```-#^`0`"````X`$``!0````1````%P``
M`+`/```1````X`X``!(```#0````$P````@````>````"````/O__V\!```(
M_O__;X`.``#___]O`@```/#__V^P#0``^O__;PX`````````````````````
M````````````````````````````````````R/T!````````````G!$``)P1
M``"<$0``G!$``)P1``"<$0``G!$``)P1``"<$0``G!$``)P1``"<$0``G!$`
M`)P1``"<$0``G!$``)P1``"<$0``G!$``)P1``"<$0``G!$``)P1``"<$0``
MG!$``)P1``"<$0``G!$``)P1``"<$0``G!$``)P1``"<$0``G!$``)P1``"<
M$0``G!$``)P1``"<$0``G!$``)P1``"<$0``G!$``)P1``"<$0``G!$``)P1
M``"<$0``G!$``)P1``"<$0``G!$``)P1``"<$0``G!$``)P1``"<$0``G!$`
M`)P1``"<$0``````````````````````````````````````````````````
M````````````````@!0````````$``(`_____UA,``"420```````%1*``!8
M2@``3$P``)Q)``!43````````#A,``!`3````````&!,``!'0T,Z("A$96)I
M86X@,3(N,BXP+34I(#$R+C(N,`!!*@```&%E86)I``$@````!35410`&!`@!
M"0$2!!,!%`$5`1<#&`$9`1H"`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N
M=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD
M>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR
M96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%232YE>&ED>``N
M96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O
M=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````
M```````````````````````````````````````````````+`````0````(`
M``!4`0``5`$``!,```````````````$`````````$P````<````"````:`$`
M`&@!```D```````````````$`````````"8````'`````@```(P!``",`0``
M(```````````````!``````````T````]O__;P(```"L`0``K`$``.@````%
M``````````0````$````/@````L````"````E`(``)0"``"`!@``!@````,`
M```$````$````$8````#`````@```!0)```4"0``FP0``````````````0``
M``````!.````____;P(```"P#0``L`T``-`````%``````````(````"````
M6P```/[__V\"````@`X``(`.``!@````!@````(````$`````````&H````)
M`````@```.`.``#@#@``T`````4`````````!`````@```!S````"0```$(`
M``"P#P``L`\``.`!```%````%0````0````(````?`````$````&````D!$`
M`)`1```,```````````````$`````````'<````!````!@```)P1``"<$0``
MY`(`````````````!`````0```""`````0````8```"`%```@!0``!PT````
M`````````!``````````B`````$````&````G$@``)Q(```(````````````
M```$`````````(X````!`````@```*1(``"D2```4$(`````````````!```
M``````"6`````0``<((```#TB@``](H```@````-``````````0`````````
MH0````$````"````_(H``/R*```$```````````````$`````````*L````.
M`````P```,#]`0#`_0``!```````````````!`````0```"W````#P````,`
M``#$_0$`Q/T```0```````````````0````$````PP````8````#````R/T!
M`,C]```(`0``!@`````````$````"````,P````!`````P```-#^`0#0_@``
M,`$`````````````!`````0```#1`````0````,```````(````!`$``````
M``````````0`````````UP````@````#````0``"`$```0`4````````````
M```$`````````-P````!````,`````````!```$`'@```````````````0``
M``$```#E`````P``<```````````7@`!`"L```````````````$`````````
H`0````,``````````````(D``0#U```````````````!````````````
